import unittest

from sql_judge_utils.mysql import MysqlDatabase as Database
from sql_judge_utils.parser import get_queries


class SampleTests(unittest.TestCase):

    @classmethod
    def setUpClass(cls):
        cls.submission_path = 'queries.sql'
        cls.submission_queries = get_queries(cls.submission_path)
        cls.valid_queries = [
            '''
                SELECT 'Feeney-Dietrich' AS p_title, 'Meedoo' AS c_title;
            '''
        ]
        cls.db1 = Database('db1')
        cls.db2 = Database('db2')

        for db in [cls.db1, cls.db2]:
            db.drop()
            db.create()
            db.initf('tests/sample_initial.sql')

    def _run_test(self, index: int):
        valid_query = self.valid_queries[index]
        submission_query = self.submission_queries[index]

        col_names_1, records_1 = self.db1.run_query(valid_query)
        col_names_2, records_2 = self.db2.run_query(submission_query)
        status, message = Database.compare_query_result(
            col_names_1,
            records_1,
            col_names_2,
            records_2
        )

        self.assertTrue(status, message)
        self.assertEqual(message, '')

    def test_query_1(self):
        self._run_test(0)
